package com.mortals.xhx.module.mid.web;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.mortals.framework.annotation.UnAuth;
import com.mortals.framework.common.Rest;
import com.mortals.framework.exception.AppException;
import com.mortals.framework.util.DateUtils;
import com.mortals.framework.web.BaseJsonBodyController;
import com.mortals.xhx.common.pdu.RespData;
import com.mortals.xhx.common.pdu.mid.MidReq;
import com.mortals.xhx.feign.mid.IMidFeign;
import com.mortals.xhx.module.certificate.model.CertificateCatalogEntity;
import com.mortals.xhx.module.certificate.model.CertificateCatalogQuery;
import com.mortals.xhx.module.certificate.pdu.ApplyLogPdu;
import com.mortals.xhx.module.certificate.service.CertificateCatalogService;
import com.mortals.xhx.module.mid.pdu.*;
import com.mortals.xhx.module.record.model.ApplyLogEntity;
import com.mortals.xhx.module.record.model.ApplyLogQuery;
import com.mortals.xhx.module.record.service.ApplyLogService;
import org.apache.commons.collections4.CollectionUtils;
import org.apache.commons.lang.StringEscapeUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 微中台数据对接
 */
@RestController
@RequestMapping("mid")
public class DataInterfaceController extends BaseJsonBodyController {

    @Autowired
    private IMidFeign iMidFeign;
    @Autowired
    private ApplyLogService applyLogService;

    @PostMapping({"certificate/spjyxkz"})
    @UnAuth
    public String spjyxkz(@RequestBody MidCertificatePdu midCertificatePdu){
        JSONObject ret = new JSONObject();
        Map<String, Object> model = new HashMap();
        byte code = 1;
        String busiDesc = "调用微中台接口生成证照";
        try {
            List<ApplyLogEntity> applyLogEntities = applyLogService.find(new ApplyLogQuery().certificateCode(midCertificatePdu.getCertificateNumber()));
            if(CollectionUtils.isNotEmpty(applyLogEntities)){
                throw new AppException("系统已存在编号："+midCertificatePdu.getCertificateNumber()+"的证照信息");
            }
            MidReq midReq = new MidReq();
            midReq.setMethod("get");
            midReq.setType(1);
            midReq.setPath("/api/edge-service-agent/1.0/c8f85e91dd297c38/zzcxxfw");
            JSONObject body = new JSONObject();
            body.put("CertificateHolderCode",midCertificatePdu.getCertificateHolderCode());
            body.put("CertificateHolderType",midCertificatePdu.getCertificateHolderType());
            body.put("CertificateType",midCertificatePdu.getCertificateType());
            body.put("CertificateNumber",midCertificatePdu.getCertificateNumber());
            body.put("UseFor",midCertificatePdu.getUseFor());
            midReq.setBody(body.toJSONString());
            Rest<String> rest = iMidFeign.trans(midReq);
            if(rest.getCode()==1){
                //String restMsg = StringEscapeUtils.unescapeJava(rest.getMsg());
                MidResponseData midResponseData = JSONObject.parseObject(rest.getMsg(),MidResponseData.class);
                if(midResponseData.getCode().equals("SUCCESS") && midResponseData.getBizRet().getIfResult().equals("0")){
                    MidIfResultInfo midIfResultInfo = JSONObject.parseObject(midResponseData.getBizRet().getIfResultInfo(),MidIfResultInfo.class);
                    if(midIfResultInfo.getHead().getStatus().equals("0")){

                        for(MidCertificateDataVO vo:midIfResultInfo.getData().getDataList()){

                            ApplyLogPdu applyLogPdu = new ApplyLogPdu();
                            //applyLogPdu.setCatalogId();
                            applyLogPdu.setCertificateCode(vo.getCertificateNumber());
                            applyLogPdu.setCertificateName(vo.getCertificateName());
                            applyLogPdu.setIssueTime(DateUtils.StrToDateTime(vo.getIssueDate(),"yyyy年MM月dd日"));
                            applyLogPdu.setEnterpriseName(vo.getCertificateHolder());
                            applyLogPdu.setPrivateID(vo.getCertificateNumber());
                            String iDCardNo = getIDCardNo(midCertificatePdu.getCertificateHolderCode());
                            applyLogPdu.setPickerIDCardNo(iDCardNo);     //取件人身份证号码
                            if(vo.getCertificateHolderType().equals("001")) {
                                applyLogPdu.setHolderType(2); //持有者类型，1：自然人，2：法人，3：自然人法人
                                applyLogPdu.setHolderIdType(2); //持有者证件类型，1：身份证，2：组织机构代码等
                            }else {
                                applyLogPdu.setHolderType(1);
                                applyLogPdu.setHolderIdType(1);
                            }
                            applyLogPdu.setHolderName(vo.getCertificateHolder());
                            applyLogPdu.setHolderIDCardNo(vo.getCertificateHolderCode());
                            JSONObject formContentJson = new JSONObject();
                            for (CertificateSurface item:vo.getSurface()){
                                //System.out.println(JSONObject.toJSON(item).toString());
                                if(item.getColumnName().equals("KZ_JingYingZheMingChen")){
                                    formContentJson.put("i_1_经营者名称",item.getValue());
                                }
                                if(item.getColumnName().equals("KZ_XuKeZhengBianHao")){
                                    formContentJson.put("i_2_许可证编号",item.getValue());
                                }
                                if(item.getColumnName().equals("KZ_SHXYDMSFZHM")){
                                    formContentJson.put("i_3_社会信用代码（身份证号码）",item.getValue());
                                }
                                if(item.getColumnName().equals("KZ_RiChangJianDuGuanLiJiGou")){
                                    formContentJson.put("i_4_日常监督管理机构",item.getValue());
                                }
                                if(item.getColumnName().equals("KZ_FaDingDaiBiaoRenFuZeRen")){
                                    formContentJson.put("i_5_法定代表人（负责人）",item.getValue());
                                    applyLogPdu.setPickerName(item.getValue());
                                }
                                if(item.getColumnName().equals("KZ_RiChangJianDuGuanLiRenYuan")){
                                    formContentJson.put("i_6_日常监督管理人员",item.getValue());
                                }
                                if(item.getColumnName().equals("KZ_ZhuSuo")){
                                    formContentJson.put("i_7_住所",item.getValue());
                                }
                                if(item.getColumnName().equals("KZ_JingYingChangSuo")){
                                    formContentJson.put("i_8_经营场所",item.getValue());
                                }
                                if(item.getColumnName().equals("KZ_ZhuTiYeTai")){
                                    formContentJson.put("i_9_主体业态",item.getValue());
                                }
                                if(item.getColumnName().equals("KZ_JingYingXiangMu")){
                                    formContentJson.put("i_10_经营项目",item.getValue());
                                }
                                if(item.getColumnName().equals("KZ_FaZhengRiQi")){
                                    formContentJson.put("i_11_发证日期",item.getValue());
                                }
                                if(item.getColumnName().equals("KZ_YouXiaoQiZhi")){
                                    formContentJson.put("i_12_有效期至",item.getValue());
                                }
                                if(item.getColumnName().equals("KZ_TouSuJuBaoDianHua")){
                                    formContentJson.put("i_13_投诉电话",item.getValue());
                                }
                                if(item.getColumnName().equals("KZ_FaZhengJiGuan")){
                                    formContentJson.put("i_14_发证机关",item.getValue());
                                }
                                if(item.getColumnName().equals("KZ_QianFaRen")){
                                    formContentJson.put("i_15_签发人",item.getValue());
                                }
                            }
                            //二维码地址
                            formContentJson.put("@qrcode_1_二维码","");
                            applyLogPdu.setFormContent(formContentJson.toJSONString());
                            applyLogService.midSaveApplyLog(applyLogPdu,"食品经营许可证");
                            ret.put("data",applyLogPdu);
                            model.put("message_info", "生成证照成功");
                        }
                    }else {
                        code = -1;
                        model.put("message_info", midIfResultInfo.getHead().getMessage());
                    }
                }else {
                    code = -1;
                    model.put("message_info", "微中台食品经营许可证查询接口调用失败");
                }
            }else {
                code = -1;
                model.put("message_info", "微中台透传接口调用失败");
            }

            this.recordSysLog(this.request, busiDesc + " 【成功】");
        }catch (Exception e){
            code = -1;
            model.put("message_info", "生成证照发生异常");
            if(e instanceof AppException){
                model.put("message_info", e.getMessage());
            }
            this.doException(this.request, busiDesc, model, e);
        }
        ret.put("code",  Integer.valueOf(code));
        ret.put("msg", model.remove("message_info"));
        return ret.toJSONString();
    }

    private String getIDCardNo(String creditNo){
        String iDCardNo = "";
        try{
            MidReq midReq = new MidReq();
            midReq.setMethod("post");
            midReq.setType(1);
            midReq.setPath("/api/edge-service-agent/v1.0/f8f532513c862c43/qyjbxxjk");
            JSONObject body = new JSONObject();
            body.put("resourceId","1395585204949856258");
            JSONObject param = new JSONObject();
            param.put("creditNo",creditNo);
            body.put("param",param);
            midReq.setBody(body.toJSONString());
            Rest<String> rest = iMidFeign.trans(midReq);
            if(rest.getCode()==1) {
                //String restMsg = StringEscapeUtils.unescapeJava(rest.getMsg());
                JSONObject responseData = JSONObject.parseObject(rest.getMsg());
                if(responseData.getString("code").equals("SUCCESS")){
                    JSONObject bizRet = responseData.getJSONObject("bizRet");
                    if(bizRet.getString("code").equals("SUCCESS")){
                        JSONObject _bizRet = bizRet.getJSONObject("bizRet");
                        JSONArray dataList = _bizRet.getJSONArray("data");
                        iDCardNo = dataList.getJSONObject(0).getString("fddbrzjhm");
                    }
                }
            }
        }catch (Exception ex){
            log.error("调用微中台接口查询营业执照信息出错",ex);
        }
        return iDCardNo;
    }

    public static void main(String[] agrs){
        String msg = "{\"msg\":\"\",\"code\":\"SUCCESS\",\"bizRet\":{\"ifResult\":\"0\",\"ifResultInfo\":\"{\\\"head\\\":{\\\"message\\\":\\\"接口调用成功\\\",\\\"status\\\":\\\"0\\\"},\\\"data\\\":{\\\"total\\\":1,\\\"dataList\\\":[{\\\"certificateType\\\":\\\"食品经营许可证\\\",\\\"certificateName\\\":\\\"食品经营许可证\\\",\\\"certificateHolder\\\":\\\"宜宾市叙州区蟹先生餐饮店\\\",\\\"certificateHolderCode\\\":\\\"92511521MA69MX6A6C\\\",\\\"certificateHolderType\\\":\\\"001\\\",\\\"issueDept\\\":\\\"宜宾市市场监督管理局\\\",\\\"issueDeptCode\\\":\\\"11511200008702664Y\\\",\\\"certificateNumber\\\":\\\"JY25115210069695\\\",\\\"certificateTypeCode\\\":\\\"11100000MB0143028R026\\\",\\\"issueDate\\\":\\\"2022年10月11日\\\",\\\"certificateValidateStart\\\":\\\"2022年10月11日\\\",\\\"certificateValidateEnd\\\":\\\"2027年10月10日\\\",\\\"surface\\\":[{\\\"columnName\\\":\\\"KZ_FaZhengJiGuan\\\",\\\"name\\\":\\\"发证机关\\\",\\\"value\\\":\\\"宜宾市市场监督管理局\\\",\\\"valueType\\\":\\\"string\\\"},{\\\"columnName\\\":\\\"KZ_JingYingXiangMu\\\",\\\"name\\\":\\\"经营项目\\\",\\\"value\\\":\\\"热食类食品制售\\\",\\\"valueType\\\":\\\"string\\\"},{\\\"columnName\\\":\\\"KZ_JingYingZheMingChen\\\",\\\"name\\\":\\\"经营者名称\\\",\\\"value\\\":\\\"宜宾市叙州区蟹先生餐饮店\\\",\\\"valueType\\\":\\\"string\\\"},{\\\"columnName\\\":\\\"KZ_YouXiaoQiZhi\\\",\\\"name\\\":\\\"有效期至\\\",\\\"value\\\":\\\"2027-10-10\\\",\\\"valueType\\\":\\\"string\\\"},{\\\"columnName\\\":\\\"KZ_ZhuTiYeTai\\\",\\\"name\\\":\\\"主体业态\\\",\\\"value\\\":\\\"餐饮服务经营者\\\",\\\"valueType\\\":\\\"string\\\"},{\\\"columnName\\\":\\\"KZ_FaZhengRiQi\\\",\\\"name\\\":\\\"发证日期\\\",\\\"value\\\":\\\"2022-10-11\\\",\\\"valueType\\\":\\\"string\\\"},{\\\"columnName\\\":\\\"KZ_SHXYDMSFZHM\\\",\\\"name\\\":\\\"社会信用代码（身份证号码）\\\",\\\"value\\\":\\\"92511521MA69MX6A6C\\\",\\\"valueType\\\":\\\"string\\\"},{\\\"columnName\\\":\\\"KZ_XuKeZhengBianHao\\\",\\\"name\\\":\\\"许可证编号\\\",\\\"value\\\":\\\"JY25115210069695\\\",\\\"valueType\\\":\\\"string\\\"},{\\\"columnName\\\":\\\"KZ_JingYingChangSuo\\\",\\\"name\\\":\\\"经营场所\\\",\\\"value\\\":\\\"四川省宜宾市叙州区航天路中段4号莱茵春天食锦美食广场内Y3号\\\",\\\"valueType\\\":\\\"string\\\"},{\\\"columnName\\\":\\\"KZ_FaDingDaiBiaoRenFuZeRen\\\",\\\"name\\\":\\\"法定代表人（负责人）\\\",\\\"value\\\":\\\"王利\\\",\\\"valueType\\\":\\\"string\\\"},{\\\"columnName\\\":\\\"KZ_ZhuSuo\\\",\\\"name\\\":\\\"住所\\\",\\\"value\\\":\\\"四川省宜宾市叙州区航天路中段4号莱茵春天食锦美食广场内Y3号\\\",\\\"valueType\\\":\\\"string\\\"},{\\\"columnName\\\":\\\"KZ_RiChangJianDuGuanLiJiGou\\\",\\\"name\\\":\\\"日常监督管理机构\\\",\\\"value\\\":\\\"宜宾市市场监督管理局\\\",\\\"valueType\\\":\\\"string\\\"},{\\\"columnName\\\":\\\"KZ_QianFaRen\\\",\\\"name\\\":\\\"签发人\\\",\\\"value\\\":\\\"黄炳华\\\",\\\"valueType\\\":\\\"string\\\"},{\\\"columnName\\\":\\\"KZ_TouSuJuBaoDianHua\\\",\\\"name\\\":\\\"投诉举报电话\\\",\\\"value\\\":\\\"12315\\\",\\\"valueType\\\":\\\"string\\\"},{\\\"columnName\\\":\\\"KZ_RiChangJianDuGuanLiRenYuan\\\",\\\"name\\\":\\\"日常监督管理人员\\\",\\\"value\\\":\\\"吴中华;骆玲\\\",\\\"valueType\\\":\\\"string\\\"}],\\\"detail\\\":[]}]}}\"}}\n";
        //String s = StringEscapeUtils.unescapeJava(msg);
        MidResponseData midResponseData = JSONObject.parseObject(msg,MidResponseData.class);
        if(midResponseData.getCode().equals("SUCCESS") && midResponseData.getBizRet().getIfResult().equals("0")){
            MidIfResultInfo midIfResultInfo = JSONObject.parseObject(midResponseData.getBizRet().getIfResultInfo(),MidIfResultInfo.class);
            if(midIfResultInfo.getHead().getStatus().equals("0")){
                for(MidCertificateDataVO vo:midIfResultInfo.getData().getDataList()){
                    System.out.println(JSONObject.toJSON(vo).toString());
                    for (CertificateSurface item:vo.getSurface()){
                        System.out.println(JSONObject.toJSON(item).toString());
                    }
                }
            }

        }
//        String msg = "{\\\"msg\\\":\\\"\\\",\\\"code\\\":\\\"SUCCESS\\\",\\\"bizRet\\\":{\\\"msg\\\":\\\"\\\",\\\"code\\\":\\\"SUCCESS\\\",\\\"bizRet\\\":{\\\"data\\\":[{\\\"lastBgrq\\\":\\\"2019-12-02\\\",\\\"hyml\\\":\\\"C\\\",\\\"clrq\\\":\\\"2005-08-31 00:00:00\\\",\\\"fddbrzjhm\\\":\\\"510624195410013012\\\",\\\"qymc\\\":\\\"广汉市康达食品有限公司\\\",\\\"jlgxsj\\\":\\\"2022-07-26 13:06:19\\\",\\\"fddbrzjlx\\\":\\\"10\\\",\\\"pripid\\\":\\\"510681000012016042700371\\\",\\\"hymlmc\\\":\\\"制造业\\\",\\\"jyfw\\\":\\\"许可项目：食品生产；食品销售；食品互联网销售。（依法须经批准的项目，经相关部门批准后方可开展经营活动，具体经营项目以相关部门批准文件或许可证件为准）一般项目：食品进出口；农副产品销售；食品销售（仅销售预包装食品）；食品互联网销售（仅销售预包装食品）；低温仓储（不含危险化学品等需许可审批的项目）。（除依法须经批准的项目外，凭营业执照依法自主开展经营活动）\\\",\\\"lastBgsxmc\\\":\\\"高级管理人员备案（董事、监事、经理等）\\\",\\\"yzbm\\\":\\\"\\\",\\\"dz\\\":\\\"四川省德阳市广汉市兴隆镇西林村（刘家坎）\\\",\\\"scztlxmc\\\":\\\"有限责任公司(自然人投资或控股)\\\",\\\"lastBgsx\\\":\\\"70\\\",\\\"id\\\":\\\"c6521e8f-d323-445e-bf6a-a6c2e6f9e766\\\",\\\"jyztmc\\\":\\\"存续（在营、开业、在册）\\\",\\\"hydmmc\\\":\\\"肉制品及副产品加工\\\",\\\"hzrq\\\":\\\"2022-06-21\\\",\\\"jyqyks\\\":\\\"2005-08-31\\\",\\\"zczbbzmc\\\":\\\"人民币\\\",\\\"qyType\\\":\\\"1\\\",\\\"zczb\\\":1000.0,\\\"hydm\\\":\\\"1353\\\",\\\"scztlxdm\\\":\\\"1130\\\",\\\"etlTime\\\":\\\"2023-05-05 15:05:49\\\",\\\"djjg\\\":\\\"510681\\\",\\\"tyshxydm\\\":\\\"91510681X208802529\\\",\\\"zczbbz\\\":\\\"156\\\",\\\"lastBghnr\\\":\\\"刘凤兴 \\\",\\\"fddbrzjlxmc\\\":\\\"中华人民共和国居民身份证\\\",\\\"djjgmc\\\":\\\"广汉市市场监督管理局\\\",\\\"lastBgqnr\\\":\\\"刘凤兴 \\\",\\\"fddbr\\\":\\\"刘凤兴\\\",\\\"dzxzqh\\\":\\\"510681\\\",\\\"jyzt\\\":\\\"1\\\"}]}}}";
//        String restMsg = StringEscapeUtils.unescapeJava(msg);
//        String iDCardNo = "";
//        JSONObject responseData = JSONObject.parseObject(restMsg);
//        if(responseData.getString("code").equals("SUCCESS")){
//            JSONObject bizRet = responseData.getJSONObject("bizRet");
//            if(bizRet.getString("code").equals("SUCCESS")){
//                JSONObject _bizRet = bizRet.getJSONObject("bizRet");
//                JSONArray dataList = _bizRet.getJSONArray("data");
//                iDCardNo = dataList.getJSONObject(0).getString("fddbrzjhm");
//            }
//            System.out.println(iDCardNo);
//        }
    }
}
