package com.mortals.xhx.module.print.service.impl;
import com.mortals.xhx.module.certificate.model.CertificateCatalogEntity;
import com.mortals.xhx.module.certificate.service.CertificateCatalogService;
import com.mortals.xhx.module.print.model.PrintCatalogQuery;
import com.mortals.xhx.module.print.model.PrintServiceEntity;
import com.mortals.xhx.module.print.service.PrintServiceService;
import org.apache.commons.collections4.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.mortals.framework.service.impl.AbstractCRUDServiceImpl;
import com.mortals.framework.exception.AppException;
import com.mortals.framework.model.Context;
import com.mortals.xhx.module.print.dao.PrintCatalogDao;
import com.mortals.xhx.module.print.model.PrintCatalogEntity;
import com.mortals.xhx.module.print.service.PrintCatalogService;

import java.util.List;

/**
* PrintCatalogService
* 证照目录打印配置 service实现
*
* @author zxfei
* @date 2022-11-21
*/
@Service("printCatalogService")
public class PrintCatalogServiceImpl extends AbstractCRUDServiceImpl<PrintCatalogDao, PrintCatalogEntity, Long> implements PrintCatalogService {

    @Autowired
    private CertificateCatalogService certificateCatalogService;
    @Autowired
    private PrintServiceService printServiceService;

    @Override
    protected void validData(PrintCatalogEntity entity, Context context) throws AppException {
        if(entity.getServiceId()==null){
            throw new AppException("打印服务id不能为空");
        }
        if(entity.getCatalogId()==null){
            throw new AppException("证照目录id不能为空");
        }
    }

    @Override
    protected void saveBefore(PrintCatalogEntity entity, Context context) throws AppException {
        super.saveBefore(entity,context);
        CertificateCatalogEntity catalogEntity = certificateCatalogService.get(entity.getCatalogId());
        if(catalogEntity == null){
            throw new AppException("证照目录id不正确");
        }
        entity.setCatalogCode(catalogEntity.getCatalogCode());
        entity.setCatalogName(catalogEntity.getCatalogName());
    }

    @Override
    public PrintCatalogEntity getPrintCatalogByService(Long serviceId, Long catalogId) throws AppException {
        PrintServiceEntity printServiceEntity = printServiceService.get(serviceId);
        if(printServiceEntity == null){
            throw new AppException("打印服务id不正确");
        }
        PrintCatalogEntity data = null;
        PrintCatalogQuery query = new PrintCatalogQuery();
        query.setCatalogId(catalogId);
        query.setServiceId(serviceId);
        List<PrintCatalogEntity> printCatalogEntityList = this.find(query);
        if(CollectionUtils.isNotEmpty(printCatalogEntityList)){
            data = printCatalogEntityList.get(0);
            data.setServiceUrl(printServiceEntity.getServiceUrl());
        }else {
            CertificateCatalogEntity catalogEntity = certificateCatalogService.get(catalogId);
            if(catalogEntity == null){
                throw new AppException("证照目录id不正确");
            }
            data = new PrintCatalogEntity();
            data.setServiceUrl(printServiceEntity.getServiceUrl());
            data.setCatalogCode(catalogEntity.getCatalogCode());
            data.setCatalogName(catalogEntity.getCatalogName());
            data.setCatalogId(catalogEntity.getId());
            data.setPrinterIp(catalogEntity.getPrinterIp());
            data.setPrinterName(catalogEntity.getPrinterName());
            data.setPaperSource(catalogEntity.getPaperSource());
        }
        return data;
    }
}